@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -45,11 +45,12 @@ class CGraph extends CGraphGeneral {
 	}
 
 	/**
-	* Get graph data
-	*
-	* @param array $options
-	* @return array
-	*/
+	 * Get graph data.
+	 *
+	 * @param array $options
+	 *
+	 * @return array
+	 */
 	public function get($options = array()) {
 		$result = array();
 		$userType = self::$userData['type'];
@@ -531,7 +532,7 @@ class CGraph extends CGraphGeneral {
 	 * Delete graphs.
 	 *
 	 * @param array $graphids
-	 * @param bool $nopermissions
+	 * @param bool  $nopermissions
 	 *
 	 * @return array
 	 */
@@ -658,56 +659,63 @@ class CGraph extends CGraphGeneral {
 	}
 
 	/**
-	 * Validate graph specific data on Create method.
-	 * Get allowed item ID's, check permissions, do all general validation and check for numeric item types.
+	 * Validate create.
 	 *
 	 * @param array $graphs
-	 *
-	 * @return void
 	 */
 	protected function validateCreate(array $graphs) {
 		$itemIds = $this->validateItemsCreate($graphs);
-		$this->validateItems($itemIds);
+		$this->validateItems($itemIds, $graphs);
 
 		parent::validateCreate($graphs);
 	}
 
 	/**
-	 * Validate graph specific data on Update method.
-	 * Get allowed item ID's, check permissions, do all general validation and check for numeric item types.
+	 * Validate update.
 	 *
 	 * @param array $graphs
 	 * @param array $dbGraphs
-	 *
-	 * @return void
 	 */
 	protected function validateUpdate(array $graphs, array $dbGraphs) {
+		// check for "itemid" when updating graph with only "gitemid" passed
+		foreach ($graphs as &$graph) {
+			if (isset($graph['gitems'])) {
+				foreach ($graph['gitems'] as &$gitem) {
+					if (isset($gitem['gitemid']) && !isset($gitem['itemid'])) {
+						$dbGitems = zbx_toHash($dbGraphs[$graph['graphid']]['gitems'], 'gitemid');
+						$gitem['itemid'] = $dbGitems[$gitem['gitemid']]['itemid'];
+					}
+				}
+				unset($gitem);
+			}
+		}
+		unset($graph);
+
 		$itemIds = $this->validateItemsUpdate($graphs);
-		$this->validateItems($itemIds);
+		$this->validateItems($itemIds, $graphs);
 
 		parent::validateUpdate($graphs, $dbGraphs);
 	}
 
 	/**
-	 * Validates graph item permissions.
+	 * Validates items.
 	 *
 	 * @param array $itemIds
-	 *
-	 * @return void
+	 * @param array $graphs
 	 */
-	protected function validateItems(array $itemIds) {
-		$allowedItems = API::Item()->get(array(
+	protected function validateItems(array $itemIds, array $graphs) {
+		$dbItems = API::Item()->get(array(
+			'output' => array('name', 'value_type'),
 			'nodeids' => get_current_nodeid(true),
 			'itemids' => $itemIds,
 			'webitems' => true,
 			'editable' => true,
-			'output' => array('name', 'value_type'),
 			'preservekeys' => true
 		));
 
 		// check if items exist and user has permission to access those items
-		foreach ($itemIds as $itemid) {
-			if (!isset($allowedItems[$itemid])) {
+		foreach ($itemIds as $itemId) {
+			if (!isset($dbItems[$itemId])) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _('No permissions to referred object or it does not exist!'));
 			}
 		}
@@ -715,11 +723,46 @@ class CGraph extends CGraphGeneral {
 		$allowedValueTypes = array(ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_UINT64);
 
 		// get value type and name for these items
-		foreach ($allowedItems as $item) {
-			if (!in_array($item['value_type'], $allowedValueTypes)) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Cannot add a non-numeric item "%1$s" to graph "%2$s".', $item['name'], $graph['name'])
-				);
+		foreach ($graphs as $graph) {
+			// graph items
+			foreach ($graph['gitems'] as $graphItem) {
+				$item = $dbItems[$graphItem['itemid']];
+
+				if (!in_array($item['value_type'], $allowedValueTypes)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, _s(
+						'Cannot add a non-numeric item "%1$s" to graph "%2$s".',
+						$item['name'],
+						$graph['name']
+					));
+				}
+			}
+
+			// Y axis min
+			if (isset($graph['ymin_itemid']) && $graph['ymin_itemid']
+					&& isset($graph['ymin_type']) && $graph['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+				$item = $dbItems[$graph['ymin_itemid']];
+
+				if (!in_array($item['value_type'], $allowedValueTypes)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, _s(
+						'Cannot add a non-numeric item "%1$s" to graph "%2$s".',
+						$item['name'],
+						$graph['name']
+					));
+				}
+			}
+
+			// Y axis max
+			if (isset($graph['ymax_itemid']) && $graph['ymax_itemid']
+					&& isset($graph['ymax_type']) && $graph['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+				$item = $dbItems[$graph['ymax_itemid']];
+
+				if (!in_array($item['value_type'], $allowedValueTypes)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, _s(
+						'Cannot add a non-numeric item "%1$s" to graph "%2$s".',
+						$item['name'],
+						$graph['name']
+					));
+				}
 			}
 		}
 	}
