@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -235,10 +235,12 @@ elseif (isset($_REQUEST['save'])) {
 		'filter' => $filter
 	);
 
-	if (isset($_REQUEST['itemid'])) {
+	if (hasRequest('itemid')) {
+		$itemId = getRequest('itemid');
+
 		DBstart();
 
-		$db_item = get_item_by_itemid_limited($_REQUEST['itemid']);
+		$dbItem = get_item_by_itemid_limited($itemId);
 
 		// unset snmpv3 fields
 		if ($item['snmpv3_securitylevel'] == ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV) {
@@ -249,14 +251,8 @@ elseif (isset($_REQUEST['save'])) {
 			$item['snmpv3_privprotocol'] = ITEM_PRIVPROTOCOL_DES;
 		}
 
-		// unset fields without changes
-		foreach ($item as $field => $value) {
-			if ($item[$field] == $db_item[$field]) {
-				unset($item[$field]);
-			}
-		}
-
-		$item['itemid'] = $_REQUEST['itemid'];
+		$item = CArrayHelper::unsetEqualValues($item, $dbItem);
+		$item['itemid'] = $itemId;
 
 		$result = API::DiscoveryRule()->update($item);
 		$result = DBend($result);
@@ -272,21 +268,25 @@ elseif (isset($_REQUEST['save'])) {
 		clearCookies($result, $_REQUEST['hostid']);
 	}
 }
-elseif (str_in_array($_REQUEST['go'], array('activate', 'disable')) && isset($_REQUEST['g_hostdruleid'])) {
-	$groupHostDiscoveryRuleId = $_REQUEST['g_hostdruleid'];
+elseif (str_in_array(getRequest('go'), array('activate', 'disable')) && hasRequest('g_hostdruleid')) {
+	$groupHostDiscoveryRuleId = getRequest('g_hostdruleid');
+	$enable = (getRequest('go') == 'activate');
 
 	DBstart();
+	$result = $enable ? activate_item($groupHostDiscoveryRuleId) : disable_item($groupHostDiscoveryRuleId);
+	$result = DBend($result);
 
-	$goResult = ($_REQUEST['go'] == 'activate')
-		? activate_item($groupHostDiscoveryRuleId)
-		: disable_item($groupHostDiscoveryRuleId);
-	$goResult = DBend($goResult);
+	$updated = count($groupHostDiscoveryRuleId);
 
-	show_messages($goResult,
-		($_REQUEST['go'] == 'activate') ? _('Discovery rules activated') : _('Discovery rules disabled'),
-		null
-	);
-	clearCookies($goResult, $_REQUEST['hostid']);
+	$messageSuccess = $enable
+		? _n('Discovery rule enabled', 'Discovery rules enabled', $updated)
+		: _n('Discovery rule disabled', 'Discovery rules disabled', $updated);
+	$messageFailed = $enable
+		? _n('Cannot enable discovery rules', 'Cannot enable discovery rules', $updated)
+		: _n('Cannot disable discovery rules', 'Cannot disable discovery rules', $updated);
+
+	show_messages($result, $messageSuccess, $messageFailed);
+	clearCookies($result, getRequest('hostid'));
 }
 elseif ($_REQUEST['go'] == 'delete' && isset($_REQUEST['g_hostdruleid'])) {
 	$goResult = API::DiscoveryRule()->delete($_REQUEST['g_hostdruleid']);
@@ -310,8 +310,10 @@ if (isset($_REQUEST['form'])) {
 else {
 	$data = array(
 		'hostid' => get_request('hostid', 0),
-		'host' => $host
+		'host' => $host,
+		'showErrorColumn' => ($host['status'] != HOST_STATUS_TEMPLATE)
 	);
+
 	$sortfield = getPageSortField('name');
 
 	// discoveries
@@ -327,10 +329,12 @@ else {
 		'limit' => $config['search_limit'] + 1
 	));
 
-	// determine, show or not column of errors
-	$data['showErrorColumn'] = ($host['status'] != HOST_STATUS_TEMPLATE);
+	$data['discoveries'] = CMacrosResolverHelper::resolveItemNames($data['discoveries']);
 
-	if (!empty($data['discoveries'])) {
+	if ($sortfield === 'status') {
+		orderItemsByStatus($data['discoveries'], getPageSortOrder());
+	}
+	else {
 		order_result($data['discoveries'], $sortfield, getPageSortOrder());
 	}
 
