@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@ class CScreenEvents extends CScreenBase {
 			$item->addRow(array(
 				zbx_date2str(_('d M Y H:i:s'), $event['clock']),
 				get_node_name_by_elid($event['objectid']),
-				$host['host'],
+				$host['name'],
 				new CLink(
 					$trigger['description'],
 					'tr_events.php?triggerid='.$event['objectid'].'&eventid='.$event['eventid']
