@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
-
+?>
+<?php
 
 /*
  * Function: get_service_status
@@ -42,7 +43,7 @@ function get_service_status($serviceid, $algorithm, $triggerid = null, $status =
 		$result = DBselect(
 			'SELECT s.status'.
 			' FROM services s,services_links l'.
-			' WHERE l.serviceupid='.$serviceid.
+			' WHERE l.serviceupid='.zbx_dbstr($serviceid).
 				' AND s.serviceid=l.servicedownid'.
 			' ORDER BY s.status'.$sort_order
 		);
@@ -77,7 +78,7 @@ function get_service_childs($serviceid, $soft = 0) {
 	$result = DBselect(
 		'SELECT sl.servicedownid'.
 		' FROM services_links sl'.
-		' WHERE sl.serviceupid='.$serviceid.
+		' WHERE sl.serviceupid='.zbx_dbstr($serviceid).
 			($soft ? '' : ' AND sl.soft=0')
 	);
 	while ($row = DBfetch($result)) {
@@ -242,7 +243,7 @@ function createServiceMonitoringTree(array $services, array $slaData, $period, &
 		);
 
 		$caption = array(new CLink(
-			array(get_node_name_by_elid($service['serviceid'], null, ': '), $service['name']),
+			array(get_node_name_by_elid($service['serviceid'], null, NAME_DELIMITER), $service['name']),
 			'report3.php?serviceid='.$service['serviceid'].'&year='.date('Y').'&period='.$periods[$period]
 		));
 		$trigger = $service['trigger'];
@@ -354,7 +355,7 @@ function update_services_rec($serviceid) {
 		'SELECT l.serviceupid,s.algorithm'.
 		' FROM services_links l,services s'.
 		' WHERE s.serviceid=l.serviceupid'.
-			' AND l.servicedownid='.$serviceid
+			' AND l.servicedownid='.zbx_dbstr($serviceid)
 	);
 	while ($row = DBfetch($result)) {
 		$serviceupid = $row['serviceupid'];
@@ -363,7 +364,7 @@ function update_services_rec($serviceid) {
 		if ($algorithm == SERVICE_ALGORITHM_MAX || $algorithm == SERVICE_ALGORITHM_MIN) {
 			$status = get_service_status($serviceupid, $algorithm);
 			add_service_alarm($serviceupid, $status, time());
-			DBexecute('UPDATE services SET status='.$status.' WHERE serviceid='.$serviceupid);
+			DBexecute('UPDATE services SET status='.$status.' WHERE serviceid='.zbx_dbstr($serviceupid));
 		}
 		elseif ($algorithm != SERVICE_ALGORITHM_NONE) {
 			error(_('Unknown calculation algorithm of service status').SPACE.'['.$algorithm.']');
@@ -371,7 +372,7 @@ function update_services_rec($serviceid) {
 		}
 	}
 
-	$result = DBselect('SELECT sl.serviceupid FROM services_links sl WHERE sl.servicedownid='.$serviceid);
+	$result = DBselect('SELECT sl.serviceupid FROM services_links sl WHERE sl.servicedownid='.zbx_dbstr($serviceid));
 	while ($row = DBfetch($result)) {
 		$serviceupid = $row['serviceupid'];
 		update_services_rec($serviceupid); // ATTENTION: recursion!!!
@@ -382,13 +383,14 @@ function update_services_rec($serviceid) {
  * Retrieves the service linked to given trigger, sets it's status to $status and propagates the status change
  * to the parent services.
  *
- * @param $triggerid
- * @param $status
+ * @param string $triggerId
+ * @param int    $status
  */
-function update_services($triggerid, $status) {
-	DBexecute('UPDATE services SET status='.$status.' WHERE triggerid='.$triggerid);
+function updateServices($triggerId, $status) {
+	DBexecute('UPDATE services SET status='.zbx_dbstr($status).' WHERE triggerid='.zbx_dbstr($triggerId));
+
+	$result = DBselect('SELECT s.serviceid FROM services s WHERE s.triggerid='.zbx_dbstr($triggerId));
 
-	$result = DBselect('SELECT s.serviceid FROM services s WHERE s.triggerid='.$triggerid);
 	while ($row = DBfetch($result)) {
 		add_service_alarm($row['serviceid'], $status, time());
 		update_services_rec($row['serviceid']);
@@ -441,7 +443,7 @@ function latest_service_alarm($serviceid, $status) {
 	$result = DBselect(
 		'SELECT sa.servicealarmid,sa.value'.
 		' FROM service_alarms sa'.
-		' WHERE sa.serviceid='.$serviceid.
+		' WHERE sa.serviceid='.zbx_dbstr($serviceid).
 		' ORDER BY sa.servicealarmid DESC', 1
 	);
 	$row = DBfetch($result);
@@ -457,7 +459,7 @@ function add_service_alarm($serviceid, $status, $clock) {
 	if (latest_service_alarm($serviceid, $status)) {
 		return true;
 	}
-	return DBexecute('INSERT INTO service_alarms (servicealarmid,serviceid,clock,value) VALUES ('.get_dbid('service_alarms', 'servicealarmid').','.$serviceid.','.$clock.','.$status.')');
+	return DBexecute('INSERT INTO service_alarms (servicealarmid,serviceid,clock,value) VALUES ('.get_dbid('service_alarms', 'servicealarmid').','.zbx_dbstr($serviceid).','.zbx_dbstr($clock).','.zbx_dbstr($status).')');
 }
 
 /**
@@ -504,16 +506,3 @@ function checkServiceTime(array $serviceTime) {
 		throw new APIException(ZBX_API_ERROR_PARAMETERS, _('Service start time must be less than end time.'));
 	}
 }
-
-/**
- * Convert 1.8 service time format (unixtime) to 2.0 format (seconds starting from Sunday).
- *
- * @param int $time
- *
- * @return int
- */
-function prepareServiceTime($time) {
-	return ($time > SEC_PER_WEEK * 2)
-		? date('w', $time) * SEC_PER_DAY + ($time - mktime(null, null, null, date('n', $time), date('j', $time), date('Y', $time)))
-		: $time;
-}
