@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2014 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -156,6 +156,8 @@ elseif (isset($_REQUEST['delete'])) {
 elseif ($_REQUEST['go'] == 'delete' && isset($_REQUEST['scripts'])) {
 	$scriptIds = $_REQUEST['scripts'];
 
+	DBstart();
+
 	$goResult = API::Script()->delete($scriptIds);
 
 	if ($goResult) {
@@ -164,6 +166,8 @@ elseif ($_REQUEST['go'] == 'delete' && isset($_REQUEST['scripts'])) {
 		}
 	}
 
+	$goResult = DBend($goResult);
+
 	show_messages($goResult, _('Script deleted'), _('Cannot delete script'));
 	clearCookies($goResult);
 
@@ -212,7 +216,7 @@ if (isset($_REQUEST['form'])) {
 		$data['groupid'] = $script['groupid'];
 		$data['access'] = $script['host_access'];
 		$data['confirmation'] = $script['confirmation'];
-		$data['enableConfirmation'] = !empty($script['confirmation']);
+		$data['enableConfirmation'] = !zbx_empty($script['confirmation']);
 		$data['hgstype'] = empty($data['groupid']) ? 0 : 1;
 	}
 
